#
# spec file for package pv
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pv
Version:        1.8.12
Release:        1.5
Summary:        Tool for monitor the progress of data through pipes
License:        GPL-3.0-or-later
Group:          System/Base
URL:            http://ivarch.com/programs/pv.shtml

#Git-Clone:     https://github.com/a-j-wood/pv
Source:         http://ivarch.com/programs/sources/%name-%version.tar.gz
Source2:        http://ivarch.com/programs/sources/%name-%version.tar.gz.txt#/%name-%version.tar.gz.asc
Source3:        %name.keyring
BuildRequires:  gcc
BuildRequires:  gettext
BuildRequires:  gettext-devel
BuildRequires:  glibc-devel
BuildRequires:  intltool
BuildRequires:  make
BuildRequires:  sysvinit-tools

%description
PV ("Pipe Viewer") is a tool for monitoring the progress of data through a
pipeline. It can be inserted into any normal pipeline between two processes
to give a visual indication of how quickly data is passing through, how long
it has taken, how near to completion it is, and an estimate of how long it
will be until completion.

%prep
%autosetup -p1

%build
%configure --enable-lfs --enable-nls --disable-debugging --docdir="%_docdir/pv"
%make_build

%install
%make_install
%find_lang %name
rm %buildroot/%_docdir/pv/INSTALL

%check
%ifnarch s390x
%make_build test
%endif

%files -f %name.lang
%license docs/COPYING
%_docdir/pv
%_bindir/pv
%_mandir/man1/pv.1*

%changelog
* Wed Jul 31 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.8.12:
  * fix detection of output block device size
  * do not treat a zero/interrupted write as an end of file
* Sun Jun 30 2024 Dirk Müller <dmueller@suse.com>
- update to 1.8.10:
  * feature: new "`--output`" option to write to a file instead
    of standard output (pull request #90) supplied by xmort
* Tue Apr 23 2024 Joshua Smith <smolsheep@opensuse.org>
- version update to 1.8.9
  * feature: new "--si" option to display and interpret size
    suffixes in multiples of 1000 rather than 1024
  * fix: continue producing progress output when the output is
    blocking writes
  * fix: honour the TMPDIR / TMP environment variables again,
    rather than hard-coding "/tmp", when using a terminal lock file
  * i18n: corrections and missing strings added to French
    translations
* Wed Feb 14 2024 pgajdos@suse.com
- version update to 1.8.5
  * Corrected percentage formatting so it does not jump from 2 to 3
    characters wide at 100%%.
  * Replaced `--remote` mechanism to use a temporary file instead
    of SysV IPC, so it can work reliably even when there are
    multiple pv instances.
  * feature: new `--discard` option to discard input as if writing
    to /dev/null.
  * feature: new `--error-skip-block` option to make `--skip-
    errors` skip whole blocks.
  * feature: use `posix_fadvise()` like cat(1) does, to improve
    efficiency.
  * security: with `--pidfile`, write to a temporary file and
    rename it into place, to improve security.
  * security: ignore _TMP_ / _TMPDIR_ environment variables when
    using a terminal lock file.
  * Only report errors about missing files when starting to
    transfer from them, not while calculating size, and behave more
    like cat(1) by skipping them and moving on.
  * Auto-calculate total line count with `--line-mode` when all
    inputs are regular files.
  * Cope with machine suspend/resume and botched timestamps.
  * If `--width` or `--height` were provided, do not change them
    when the window size changes.
  * When a file descriptor position in `--watchfd` moves backwards,
    show the rate using the correct prefix.
  * Rewrite terminal state save/restore so state is not
    intermittently garbled on exit when using `--cursor`.
  * Licensing change from Artistic 2.0 to GPLv3+.
* Thu Nov 30 2023 pgajdos@suse.com
- disable testsuite for s390x [bsc#1215338]
- remove _constraints again as it didn't help
- deleted sources
  - _constraints (not needed)
* Wed Nov 15 2023 pgajdos@suse.com
- increase required memory in _constraints [bsc#1217165]
  (tests still fails in ETA related tests)
* Tue Sep 26 2023 pgajdos@suse.com
- add _constraints [bsc#1215338]
* Sun Jul 30 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.7.24
  * correct terminal size detection (was broken by 1.7.17)
* Fri Jul 28 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.7.18
  * New "--sync" option to flush cache to disk after every write
  * New "--direct-io" option to bypass cache
* Mon Jul 17 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.7.0
  * The "--size" option now accepts "@filename" to use the size
    of another file.
  * New "--bits" option to show bit count instead of byte count.
  * New "--average-rate-window" option, to set the window over
    which the average rate is calculated, also used for ETA.
  * The "--watchfd" option will now show relative filenames, if
    they are under the current directory.
  * Add burst rate limit to transfer, so rate limits are not
    broken by bursty traffic.
  * Corrected elapsed time display to show as D:HH:MM:SS after 1
    day, like the ETA does.
* Fri Nov  5 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.6.20
  * Starting pv in the background no longer immediately stops
    unless the transfer is to/from the terminal.
  * Using -B, -A, or -T now switches on -C implicitly.
* Tue Sep  8 2020 Jan Engelhardt <jengelh@inai.de>
- Trim old specfile constructs.
* Mon Aug  7 2017 jengelh@inai.de
- Update to new upstream release 1.6.6
  * Fix target buffer size (-B) being ignored
  * Cap read/write sizes, and check elapsed time during read/write
    cycle to avoid display hangs with large buffers or slow media.
  * Report error in "-d" if process fd directory is unreadable, or
    if process disappears before we start the main loop.
* Fri Mar 27 2015 jengelh@inai.de
- Update to new upstream release 1.6.0
  * new option "-D" / "--delay-start" to only show bar after
  N seconds
  * new option "--fineta" / "-I" to show ETA as time of day rather
  than time remaining
  * change ETA (--eta / -e) so that days are given if the hours
  remaining are 24 or more
  * repeat read and write attempts on partial buffer fill/empty to
  work around post-signal transfer rate drop
  * output errors on a new line to avoid overwriting transfer bar
* Mon Dec  8 2014 jengelh@inai.de
- Update to new upstream release 1.5.7
  * show KiB instead of incorrect kiB
  * work around awk bug in tests/016-numeric-timer in decimal ","
  locales
* Mon May  5 2014 jengelh@inai.de
- Update to new upstream release 1.5.3
  * Added new display options --buffer-percent, --last-written
  * New transfer option --no-splice
  * New option --watchfd to monitor file descriptor status of another
  process, rather than moving data from stdin to stdout.
* Mon Aug 12 2013 jengelh@inai.de
- Update to new upstream release 1.4.12
  * A fix for splice() not using stdin was implemented
  * A new -0/--null option has been added to count NUL-terminated
  "lines"
* Wed Jun  5 2013 jengelh@inai.de
- Add explicit BuildRequires for usleep
* Fri Jan 25 2013 jengelh@inai.de
- Update to new upstream release 1.4.6
  * updated manual page to show known problem with "-R" on Cygwin
  * added patch from Pawel Piatek to omit O_NOFOLLOW in AIX
* Mon Dec 24 2012 jengelh@inai.de
- Update to new upstream release 1.4.4
  * fix crash when progress is displayed with too-small terminal
  * new option --skip-errors
  * new option --stop-at-size to stop after --size bytes
  * autodetermine size if stdout is a block device
  * fix a use-after-free bug
* Tue Nov 20 2012 jengelh@inai.de
- Update to new upstream release 1.3.9
  * new --pidfile option to save process ID to a file
  * integrated patch for --numeric with --timer and --bytes
  * removed signalling from --remote to prevent accidental process kills
  * new --format option and allow --format parameters to be sent
  with --remote
* Sat Sep  1 2012 jengelh@inai.de
- Update to new upstream release 1.3.4
  * new --disable-splice configure script option
  * fixed line mode size count with multiple files
- Use RH-friendly make install
* Mon Jun 25 2012 pascal.bleser@opensuse.org
- update to 1.3.1:
  * do not use splice() if the write buffer is not empty
- changes from 1.3.0:
  * fix 1024-boundary display garble
  * use splice(2) where available
  * added known bugs section of the manual page
  * use IEEE1541 units
  * bug with rate limit under 10 fixed
  * speed up PV line mode
* Tue May 22 2012 jengelh@inai.de
- Feed through format_spec_file to get copyright header required
  for factory inclusion
* Mon Feb 20 2012 jengelh@medozas.de
- Update license field to SPDX format
- Use short URL
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
* Fri Jan 14 2011 pascal.bleser@opensuse.org
- change RPM group to System/Base instead of invalid group System/Tools
* Tue Dec 14 2010 pascal.bleser@opensuse.org
- update to 1.2.0:
  * an average rate display option was added to better show progress with bursty traffic
  * a consistent exit status is set to help script writers
  * various minor cleanups and bug fixes were made
* Tue Nov  9 2010 pascal.bleser@opensuse.org
- moved to utilities
* Thu Mar  6 2008 guru@unixtech.be
- new upstream version
* Mon Oct 22 2007 guru@unixtech.be
- moved to openSUSE Build Service
* Thu Aug 30 2007 guru@unixtech.be
- new upstream version
* Fri Aug  3 2007 guru@unixtech.be
- new upstream version
* Mon Feb  5 2007 guru@unixtech.be
- new upstream version
* Tue Feb 28 2006 guru@unixtech.be
- new upstream version
* Thu Dec  8 2005 guru@unixtech.be
- added debuginfo support
- use makeinstall macro
- use configure macro
- added autoreconf
- use install_info SUSE macros
- use find_lang macro
- rewrote spec file
- new upstream version
* Fri Jun 17 2005 guru@unixtech.be
- version 0.9.1
* Sun Nov  7 2004 guru@unixtech.be
- version 0.8.9
* Mon May  3 2004 guru@unixtech.be
- version 0.8.5
* Sun Apr 25 2004 guru@unixtech.be
- version 0.8.2
* Tue Apr 20 2004 guru@unixtech.be
- version 0.8.1
* Sun Feb  8 2004 guru@unixtech.be
- version 0.7.0
* Tue Jan  6 2004 guru@unixtech.be
- new spec-file
